@@ -6,7 +6,7 @@ use warnings;
 use Text::Autoformat;
 use WWW::Wikipedia;
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 
 =head1 NAME
 
@@ -289,7 +289,7 @@ sub _parse {
         }
 
         ## {{ disambig }}
-        elsif ( $raw =~ /\G{{ *(.*?) *}}/ ) {
+        elsif ( $raw =~ /\G\{\{ *(.*?) *\}\}/ ) {
             ## ignore for now
             $self->{ cursor } += length( $& ) - 1;
             next;
